'''
% Log Cumulative Hazard Plot
% This program generates log-cumulative hazard plot that show the relationship between the cumulative hazard and age of a population.
%
% This program requires the matplotlib.
%
%    matplotlib ==> http://matplotlib.sourceforge.net/
%
% Last Update: 2011.06.03
% By Jae-Seong Yang, destine@postech.ac.kr
'''

from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
from matplotlib.figure import Figure
from matplotlib.lines import Line2D
from matplotlib.patches import Rectangle
import SurvivalData
import matplotlib.font_manager


def LogCumulativeHazardPlots( prefix, conditions ):
    if len( conditions ) < 6:
        _figsize = (5,3)
    else:
        _figsize = (7.5,4.5)

    color_list = [ 'b', 'r', 'g', 'c', 'm', 'y', 'k' ]
    style_list = [ '-', '--', '-.', ':' ]
    marker_list = [ 'o', '^', 's', 'D', 'v', '<', '>', 'p', '*', 'h', 'H', '+', 'x', 'd' ]

    fig = Figure( figsize= _figsize )
    canvas = FigureCanvas(fig)
    ax = fig.add_subplot(111)
    fig.subplots_adjust( top=0.95, bottom=0.15 )

    index = 0
    for aData in conditions:
        c = color_list[ index % len( color_list ) ]
        s = style_list[ index % len( style_list ) ]
        m = marker_list[ index % len( marker_list ) ]
        name = aData.name.strip().replace( "\t", " " )
        l, = ax.plot( aData.timelist_mot, aData.mortality, c+s+m, label = name , linewidth=2)
        l.set_clip_on( False )
        index += 1

    prop = matplotlib.font_manager.FontProperties(size=10) 
    leg = ax.legend( numpoints = 1, loc = 4, prop=prop )
    leg.get_frame().set_alpha(0)

    xx = ax.get_xaxis()
    xx.set_ticks_position( "bottom" )
    yy = ax.get_yaxis()
    yy.set_ticks_position( "left" )

    ax.set_xlabel( "Time (days)" )
    ax.set_ylabel( 'ln(cumulative hazard)' )
    fig.savefig('%s.png' % prefix)
    fig.savefig('%s.ps' % prefix)
    fig.savefig('%s.pdf' % prefix)

    ## RAW DATA For Excel
    fout = open( "%s.txt" % prefix, "w" )
    for aData in conditions:
        fout.write( "%% %s\n" % aData.name )
        fout.write( "Time (days)\tln(cumulative hazard)\n" )
        for i in range( 0, len( aData.timelist_mot ) ):
            fout.write( "%d\t%f\n" % ( aData.timelist_mot[i], aData.mortality[i] ) )
        fout.write( "\n" )
    fout.close()


def LogCumulativeHazardPlot( prefix, aData1, aData2 ):
    fig = Figure( figsize=(5, 4) )
    canvas = FigureCanvas(fig)
    ax = fig.add_subplot(111)
    name = aData1.name.strip().replace( "\t", " " )
    l, = ax.plot( aData1.timelist_mot, aData1.mortality, 'bo-', label = name )
    l.set_clip_on( False )
    [a, b, RR] = linreg( aData1.timelist_mot, aData1.mortality )

    name = aData2.name.strip().replace( "\t", " " )
    l, = ax.plot( aData2.timelist_mot, aData2.mortality, 'gD-', label = name )
    l.set_clip_on( False )

    prop = matplotlib.font_manager.FontProperties(size=10) 
    leg = ax.legend( numpoints = 1, loc = 4, prop=prop )
    leg.get_frame().set_alpha(0)

    xx = ax.get_xaxis()
    xx.set_ticks_position( "bottom" )
    yy = ax.get_yaxis()
    yy.set_ticks_position( "left" )

    ax.set_xlabel( "Time (days)" )
    ax.set_ylabel( 'ln(-ln(fraction survived))' )
    fig.savefig('%s.png' % prefix)
    fig.savefig('%s.ps' % prefix)
    fig.savefig('%s.pdf' % prefix)

    ## RAW DATA For Excel
    fout = open( "%s.txt" % prefix, "w" )
    fout.write( "%% %s\n" % aData1.name )
    fout.write( "Time (days)\tln(-ln(fraction survived))\n" )
    for i in range( 0, len( aData1.timelist_mot ) ):
        fout.write( "%d\t%f\n" % ( aData1.timelist_mot[i], aData1.mortality[i] ) )

    fout.write( "\n%% %s\n" % aData2.name )
    fout.write( "Time (days)\tln(-ln(fraction survived))\n" )
    for i in range( 0, len( aData2.timelist_mot ) ):
        fout.write( "%d\t%f\n" % ( aData2.timelist_mot[i], aData2.mortality[i] ) )

    fout.close()


            
if __name__ == "__main__":
    conditions = SurvivalData.ReadDataFromFile( "sample.txt" )

    SurvivalData.CalculateSubplotData( conditions )
    LogCumulativeHazardPlots( "log_cumulative_hazard_plot", conditions )
